(*liealgun.m *)
(****************************************************************************** 
This package contains definitions and procedures for the unitary and 
special unitary Lie algebras. It is a continuation of liealg.m, which it needs.
The concepts of this package are developed in the Notebook liealgeb.nb; for 
details and applications see this notebook. Furthermore this package needs 
the Package Declare.m of Pekka Janhunen, in 
http://www.mathsource.com/Content22/Enhancements/Algebraic/0202-149.


Author: Rolf Sulanke 

Address:
sulanke@mathematik.hu-berlin.de 
Homepage: 
http://www-irm.mathematik.hu-berlin.de/~sulanke/
  
For comments, hints, and corrections the author will be very thankful.
  
Date : November 20,  1999
***********************************************************************)
  
(*Keywords: indefinite scalar products, Lie algebra,
  unitary Lie algebra, orthogonalization, Killing form, center.*)
  
BeginPackage["liealgun`",{"liealg`", "Declare`"}]
 
(*The concepts introduced in this package depend on the dimension dim of the \
underlying vector space (= the order of the square matrices) and, 
in the pseudo-unitary case, the index ind of the (non - degenerate, 
hermitean) scalar product on this space.  dim and ind must be defined in \
the Global Context before importing the package!

Remark: The implementation of the pseudo-unitary  Lie aalgebras is left to the
interested user...*)

(*The usages*)

ubasisa::usage = "ubasisa[i,j, n:dim] is an element of the 
standard basis of the unitary Lie algebra u(n)."

ubasisb::usage = "ubasisb[i,j, n:dim] is an element of the 
standard basis of the unitary Lie algebra u(n)."

ubasisc::usage = "ubasisc[i, n:dim] is an element of the 
standard basis of the unitary Lie algebra u(n)."

ubasis::usage = "ubasis[n:dim] is the 
standard basis of the unitary Lie algebra u(n)."

uelm::usage = "uelm[a, n:dim] is the symbolic element of the unitary 
Lie algebra u(n) with coordinates a[i]."

ucobasisa::usage = "ucobasisa[i,j, n:dim] is an element of the 
standard cobasis of the unitary Lie algebra u(n)."

ucobasisb::usage = "ucobasisb[i,j, n:dim] is an element of the 
standard cobasis of the unitary Lie algebra u(n)."

ucobasisc::usage = "ucobasisc[i, n:dim] is an element of the 
standard cobasis of the unitary Lie algebra u(n)."

ucobasis::usage = "ucobasis[n:dim] is the 
standard cobasis of the unitary Lie algebra u(n)."


ukilling::usage = "ukilling[a, b, n:dim] is the Killing form of the 
unitary Lie algebra u(n)."

subasis::usage = "subasis[n:dim] is the 
standard basis of the special unitary Lie algebra su(n)."

suelm::usage = "uelm[a, n:dim] is the symbolic element of the specialm unitary 
Lie algebra su(n) with coordinates a[i]."

(* Some rules for the function Conjugate: *)

Unprotect[Conjugate]

Conjugate[x_?RealQ +I*y_?RealQ]:=x - I*y

Conjugate[x_?RealQ] := x

Conjugate[I*x_?RealQ] := -I*x

Protect[Conjugate]

Begin["`Private`"]

dim := Global`dim;

ind := Global`ind;

(*The basis of u(n) *)

ubasisa[i_, j_, n_:dim] := obm[i, j, n] /; (i < j && j <= n)

ubasisb[i_, j_, n_:dim] := (basismatrix[i, j, n] + basismatrix[j, i, n])*I/;(i < j && j <= n)

ubasisc[i_, n_:dim] := basismatrix[i, i, n]*I /; (i <= n)

ubasis[n_:dim] := 
  Join[Flatten[
      Join[Table[ubasisa[i, j, n], {j, 2, n}, {i, 1, j - 1}], 
        Table[ubasisb[i, j, n], {j, 2, n}, {i, 1, j - 1}]], 1], 
    Table[ubasisc[i, n], {i, n}]]


(*The general element of the Lie algebra u(n) *)

uelm[a_,n_:dim] :=Module[{k, c=Table[a[k], {k,  n^2}]}, Declare[c,Real];
			 Sum[ubasis[n][[k]]*a[k], {k, n^2}]]
			 
(*The cobasis of u(n) *)
			 
ucobasisa[i_,j_,n_:dim][m_?MatrixQ]:= Re[cobasis[i,j,n][m]]/;(i<j&&j<=n)

ucobasisb[i_,j_,n_:dim][m_?MatrixQ]:= Im[cobasis[i,j,n][m]]/;(i<j&&j<=n)

ucobasisc[i_,n_:dim][m_?MatrixQ]:= Im[cobasis[i,i,n][m]]/;(i<=n)

ucobasis[n_:dim][m_?MatrixQ] :=
  Join[Flatten[
      Join[Table[ucobasisa[i,j,n][m],{j, 2,n},{i,1,j-1}],
        Table[ucobasisb[i,j,n][m],{j, 2,n},{i,1,j-1}]], 1],
    Table[ucobasisc[i,n][m], {i,n}]]

(*The Killing form of u(n) *)

ukilling[x_?MatrixQ, y_?MatrixQ,n_:dim] := 
  Sum[ucobasis[n][commute[x,commute[y,ubasis[n][[i]]]]][[i]],{i, n^2}]
  
(*The special unitary Lie algebra su(n) *)

subasis[n_:dim] := Join[Table[ubasis[n][[i]], {i, n*(n-1)}],
    Table[ubasis[n][[j]] - ubasis[n][[n^2]], {j,n*(n-1)+1, n^2 -1}]]

suelm[a_, n_:dim] := Module[{k, c=Table[a[k], {k,  n^2}]}, Declare[c,Real];
			 Sum[subasis[n][[k]]*a[k], {k, n^2-1}]]

End[]

Protect[ubasisa, ubasisb, ubasisc, ubasis, ucobasisa, ucobasisb, ucobasisc, 
ucobasis, uelm, ukilling, subasis, suelm]

EndPackage[]

